<?php
namespace YpmPopup;
use \YpmConfig;
use ypmFrontend\IncludeManager;
use ypmFrontend\PopupLoader;
use \YpmFunctions;
use \YpmShowReviewNotice;

class Actions
{
	private $postTypeObj;

	public function setPostTypeObj($postTypeObj)
	{
		$this->postTypeObj = $postTypeObj;
	}

	public function getPostTypeObj()
	{
		return $this->postTypeObj;
	}

	public function __construct()
	{
		$this->init();
	}

	public function init()
	{
		add_action('init', array($this, 'postTypeInit'));
		add_action('add_meta_boxes', array($this, 'addMetaBoxes'));
		register_activation_hook(YPM_MAIN_FILE,  array($this, 'activate'));
		register_deactivation_hook(YPM_MAIN_FILE,  array($this, 'deactivate'));
		register_uninstall_hook(YPM_MAIN_FILE,  array(__CLASS__, 'uninstall'));
		add_action('admin_init', array($this, 'pluginRedirect'));

		add_action('save_post', 'YpmSavePopup::savePopupData', 10, 3);
		add_action('admin_enqueue_scripts', 'YpmPopup\Style::enqueueStyles');

		add_shortcode('ypm_popup', array($this, 'ypmShortCode'));
		add_action('wp_enqueue_scripts', array($this, 'enqueueScripts'));
		add_action('media_buttons', array($this, 'ypmPopupMediaButton'), 11);
		add_action('media_buttons', array($this, 'ypmPopupMediaModules'), 11);
		add_action('admin_footer', array($this, 'ypmPopupMediaButtonThickboxs'));
		add_action('admin_footer', array($this, 'ypmPopupModulesTickboxs'));
		add_action('add_meta_boxes', array($this, 'pageSelection'));
		add_action('plugins_loaded', array($this, 'ypmPluginLoaded'));

		add_action('admin_head', array($this, 'adminHead'));
		$this->revieNotice();
	}

	public function ypmPopupMediaButton()
	{
		YpmMediaButton::addMediaButton();
	}

	public function ypmPopupMediaModules()
	{
		YpmMediaButton::addMediaModuleButton();
	}

	public function ypmPopupMediaButtonThickboxs()
	{
		YpmMediaButton::ypmThickbox();
	}

	public function ypmPopupModulesTickboxs()
	{
		YpmMediaButton::ypmModulesThickbox();
	}

	public function ypmShortCode($args, $content)
	{
		$obj = new YpmShortcode();

		$obj->setAttrs($args);
		$obj->setContent($content);

		return $obj->render();
	}

	public function enqueueScripts()
	{
		$popupLoaderObj = PopupLoader::instance();
		if (is_object($popupLoaderObj)) {
			$popupLoaderObj->loadPopups();
		}
	}

	public function postTypeInit()
	{
		add_action('wp_head', array($this, 'ypmHeadAction'));
		$postType = new \YpmRegistration();
		$this->setPostTypeObj($postType);
	}

	public function addMetaBoxes()
	{
		$this->getPostTypeObj()->addMetaBoxes();

		if(YPM_POPUP_PKG == YPM_POPUP_FREE) {
			$this->getPostTypeObj()->upgradeToProMetabox();
		}

		$typeObj = $this->getPostTypeObj();
		$metaboxes = array(
			'popup_master_display_rules' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Display rules', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupDisplayRules')
			),
			'popup_master_open_events' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Open events', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupOpenEvents')
			),
			'popup_master_dimension' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Popup dimensions', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupDimensionsOptions')
			),
			'popup_master_options' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('General', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupGeneralOptions')
			),
			'popup_master_settings' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Settings', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupGeneralSettings')
			),
			'popup_master_exit' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Exit intent', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupExitIntent')
			),
			'popup_master_customFunctionality' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Custom functionality', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'customFunctionality')
			),
			'popup_master_conditions' => array(
				'support_post_type' => array(YPM_POPUP_POST_TYPE),
				'label' => __('Conditions', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupConditions')
			),
			'facebook_options' => array(
				'support_post_type' => array(YPM_FACEBOOK_POST_TYPE),
				'label' => __('Facebook options', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupFacebookOptions')
			),
			'youtube_options' => array(
				'support_post_type' => array(YPM_YOUTUBE_POST_TYPE),
				'label' => __('Youtube options', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupYoutubeOptions')
			),
			'ifranme_options' => array(
				'support_post_type' => array(YPM_IFRAME_POST_TYPE),
				'label' => __('Facebook options', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupIframeOptions')
			),
			'social_options' => array(
				'support_post_type' => array(YPM_SOCIAL_POST_TYPE),
				'label' => __('Social options', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'popupSocialOptions')
			),
			'contact_fields' => array(
				'support_post_type' => array(YPM_CONTACT_POST_TYPE),
				'label' => __('Contact form fields', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'contactFormFields')
			),
			'popup_master_support_metabox' => array(
				'support_post_type' =>  'allTypes',
				'label' => __('Support', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'support'),
				'possition' => 'side'
			),
			'popup_master_shortcode_metabox' => array(
				'support_post_type' =>  'allTypes',
				'label' => __('Info', YPM_POPUP_TEXT_DOMAIN),
				'callback' => array($typeObj, 'info'),
				'possition' => 'side'
			),
		);
		$metaboxes = apply_filters('ypmMetaboxes', $metaboxes);
		$typeObj->renderMetaboxes($metaboxes);
	}

	public function ypmHeadAction()
	{
		new Header();
	}

	public function pageSelection()
	{
		$screens = array('post', 'page');
		foreach ($screens as $screen) {
			add_meta_box('ypmSelectedPopup', __('Select popup maker on page load', YPM_POPUP_TEXT_DOMAIN), array($this, 'pageSelectionMetaBox'), $screen, 'side');
		}
	}

	public function pageSelectionMetaBox()
	{
		$popupData = Popup::getPopupIdTitleData();
		$metaboxData = array('' => 'Not Selected')+ $popupData;
		$postId = '';

		if(!empty($_GET['post'])) {
			$postId = $_GET['post'];
		}
		$popupSelectedId = get_post_meta($postId, 'ypm-metabox-popup');
		echo YpmFunctions::createSelectBox($metaboxData, $popupSelectedId, array('id' => 'ypm-metabox-popup-id', 'name' => 'ypm-metabox-popup'));
	}

	public function ypmPluginLoaded()
	{
		load_plugin_textdomain(YPM_POPUP_TEXT_DOMAIN, false, YPM_FOLDER_NAME.'/lang/');
	}

	public function activate()
	{
		Installer::install();
	}

	public function deactivate()
	{
		delete_option('ypm_redirect');
	}

	public static function uninstall()
	{
		Installer::uninstall();
	}

	public function adminHead()
	{
		$script = '';
		$editUrl = admin_url('edit.php');
		ob_start();
		?>
		<script>
			jQuery(document).ready(function() {
				jQuery('[href*="page=<?php echo YPM_FACEBOOK_POST_TYPE; ?>"]').attr("href", "<?php echo add_query_arg('post_type', YPM_FACEBOOK_POST_TYPE, $editUrl); ?>");
				jQuery('[href*="page=<?php echo YPM_YOUTUBE_POST_TYPE; ?>"]').attr("href", "<?php echo add_query_arg('post_type', YPM_YOUTUBE_POST_TYPE, $editUrl); ?>");
				jQuery('[href*="page=<?php echo YPM_CONTACT_POST_TYPE; ?>"]').attr("href", "<?php echo add_query_arg('post_type', YPM_CONTACT_POST_TYPE, $editUrl); ?>");
			});
		</script>
		<?php
		$script .= ob_get_contents();
		ob_end_clean();
		if (YPM_POPUP_PKG == YPM_POPUP_FREE) {
			$script .=  '<script>';
			$script .= "jQuery(document).ready(function() {jQuery('[href*=\"ypmsocial\"], [href*=\"ypmiframe\"], [href*=\"ypmcontactform\"]').attr(\"href\", '".YPM_POPUP_PRO_URL."').attr('target', '_blank');})";
			$script .= '</script>';
		}

		echo $script;
	}

	private function revieNotice()
	{
		add_action('admin_notices', array($this, 'showReviewNotice'));
		add_action('network_admin_notices', array($this, 'showReviewNotice'));
		add_action('user_admin_notices', array($this, 'showReviewNotice'));
	}

	public function showReviewNotice()
	{
		echo new YpmShowReviewNotice();
	}

	public function pluginRedirect()
	{
		if (!get_option('ypm_redirect') && post_type_exists(YPM_POPUP_POST_TYPE)) {
			update_option('ypm_redirect', 1);
			exit(wp_redirect(admin_url('edit.php?post_type='.YPM_POPUP_POST_TYPE)));
		}
	}
}