<?php
namespace YpmPopup;
require_once(YPM_POPUP_HELPERS.'ConfigDataHelper.php');

class DataConfig
{
	public static function init()
	{
		self::conditionInit();
		self::defaultValues();
	}

	public static function conditionInit()
	{
		self::globalDisplaySettings();
		self::conditionsSettings();
		self::eventsSettings();
	}

	private static function eventsSettings()
	{
		global $YPM_EVENTS_SETTINGS_CONFIG;

		$keys = array(
			'select_settings' => 'Select settings',
			'Onload' => 'On Load',
		);

		$keys = apply_filters('ypmEventConditionsKeys', $keys);
		$values = array(
			'key1' => $keys,
			'key2' => array('is' => 'Is', 'isnot' => 'Is not'),
			'Onload' => ''
		);

		$attributes = array(
			'key1' => array(
				'label' => __('Select Conditions'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'class' => 'ypm-condition-select js-ypm-select js-conditions-param',
					'value' => ''
				)
			),
			'key2' => array(
				'label' => __('Select Conditions'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'class' => 'ypm-condition-select js-ypm-select',
					'value' => ''
				)
			),
			'Onload' => array(
				'label' => __('Delay'),
				'fieldType' => 'input',
				'allowFromFirstValue' => false,
				'fieldAttributes' => array(
					'class' => 'form-control js-ypm-select'
				)
			)
		);

		$values = apply_filters('ypmEventConditionsValues', $values);
		$attributes = apply_filters('ypmEventConditionsAttributes', $attributes);

		$YPM_EVENTS_SETTINGS_CONFIG = array(
			'keys' => $keys,
			'values' => $values,
			'attributes' => $attributes
		);
	}

	private static function conditionsSettings()
	{
		global $YPM_CONDITIONS_SETTINGS_CONFIG;
		$keys = array(
			'select_settings' => 'Select settings'
		);

		$keys = apply_filters('ypmConditionConditionsKeys', $keys);

		$values = array(
			'key1' => $keys,
			'key2' => array('is' => 'Is', 'isnot' => 'Is not')
		);

		$attributes = array(
			'key1' => array(
				'label' => __('Select Conditions'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'class' => 'ypm-condition-select js-ypm-select js-conditions-param',
					'value' => ''
				)
			),
			'key2' => array(
				'label' => __('Select Conditions'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'class' => 'ypm-condition-select js-ypm-select',
					'value' => ''
				)
			)
		);

		$values = apply_filters('ypmConditionConditionsValues', $values);
		$attributes = apply_filters('ypmConditionConditionsAttributes', $attributes);

		$YPM_CONDITIONS_SETTINGS_CONFIG = array(
			'keys' => $keys,
			'values' => $values,
			'attributes' => $attributes
		);
	}

	private static function globalDisplaySettings()
	{
		global $YPM_DISPLAY_SETTINGS_CONFIG;

		$keys = array(
			'select_settings' => 'Select settings',
			'everywhere' => 'Everywhere',
			'selected_post' => 'Select posts',
			'all_post' => 'All posts',
			'selected_page' => 'Select pages',
			'all_page' => 'All pages',
		);

		$keys = apply_filters('ypmConditionsDisplayKeys', $keys);

		$values = array(
			'key1' => $keys,
			'key2' => array('is' => 'Is', 'isnot' => 'Is not'),
			'selected_post' => array(),
			'all_post' => array(),
			'selected_page' => array(),
			'all_page' => array(),
			'everywhere' => array()
		);

		$attributes = array(
			'key1' => array(
				'label' => __('Select Conditions'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'class' => 'ypm-condition-select js-ypm-select js-conditions-param',
					'value' => ''
				)
			),
			'key2' => array(
				'label' => __('Select Conditions'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'class' => 'ypm-condition-select js-ypm-select',
					'value' => ''
				)
			),
			'selected_post' => array(
				'label' => __('Select Post(s)'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'data-post-type' => 'post',
					'data-select-type' => 'ajax',
					'multiple' => 'multiple',
					'class' => 'ypm-condition-select js-ypm-select',
					'value' => ''
				)
			),
			'selected_page' => array(
				'label' => __('Select Page(s)'),
				'fieldType' => 'select',
				'fieldAttributes' => array(
					'data-post-type' => 'page',
					'data-select-type' => 'ajax',
					'multiple' => 'multiple',
					'class' => 'ypm-condition-select js-ypm-select',
					'value' => ''
				)
			),
		);

		$values = apply_filters('ycdConditionsDisplayValues', $values);
		$attributes = apply_filters('ycdConditionsDisplayAttributes', $attributes);

		$YPM_DISPLAY_SETTINGS_CONFIG = array(
			'keys' => $keys,
			'values' => $values,
			'attributes' => $attributes
		);
	}

	public static function defaultValues() {
		global $YpmDefaults;
		global $YpmDefaultsData;
		global $YpmPostTypesInfo;

		$options = array();

		$exitMode = array(
			'soft' => __('Soft mode', YPM_POPUP_TEXT_DOMAIN),
			'agressive' => __('Aggressive mode', YPM_POPUP_TEXT_DOMAIN),
			'softAgres' => __('Soft and Aggressive modes', YPM_POPUP_TEXT_DOMAIN),
			'alert' => __('Aggressive without popup', YPM_POPUP_TEXT_DOMAIN)
		);

		$socialThemes = array(
			'flat' => __('Flat', YPM_POPUP_TEXT_DOMAIN),
			'classic' => __('Classic', YPM_POPUP_TEXT_DOMAIN),
			'minima' => __('Minima', YPM_POPUP_TEXT_DOMAIN),
			'plain' => __('Plain', YPM_POPUP_TEXT_DOMAIN)
		);

		$socialShareIn = array(
			'blank' => __('Blank', YPM_POPUP_TEXT_DOMAIN),
			'popup' => __('Inside window', YPM_POPUP_TEXT_DOMAIN),
			'self' => __('Self', YPM_POPUP_TEXT_DOMAIN)
		);

		$socialFontSizes = array(
			'8' => '8',
			'10' => '10',
			'12' => '12',
			'14' => '14',
			'16' => '16',
			'18' => '18',
			'20' => '20',
			'24' => '24'
		);

		$socialThemeShareCount = array(
			'true' => __('True', YPM_POPUP_TEXT_DOMAIN),
			'false' => __('False', YPM_POPUP_TEXT_DOMAIN),
			'inside' => __('Inside', YPM_POPUP_TEXT_DOMAIN)
		);

		$fblikeLayout = array(
			'standard' => __('Standard', YPM_POPUP_TEXT_DOMAIN),
			'button_count' => __('Button with count', YPM_POPUP_TEXT_DOMAIN),
			'box_count' => __('Box with count', YPM_POPUP_TEXT_DOMAIN),
			'button' => __('Button', YPM_POPUP_TEXT_DOMAIN)
		);

		$fblikeShareLayout = array(
			'box_count' => __('Box with count', YPM_POPUP_TEXT_DOMAIN),
			'button_count' => __('Button with count', YPM_POPUP_TEXT_DOMAIN),
			'button' => __('Button', YPM_POPUP_TEXT_DOMAIN)
		);

		$fblikeAction = array(
			'like' => __('Like', YPM_POPUP_TEXT_DOMAIN),
			'recommend' => __('Recommend', YPM_POPUP_TEXT_DOMAIN)
		);

		$fblikeSize = array(
			'small' => __('Small', YPM_POPUP_TEXT_DOMAIN),
			'large' => __('Large', YPM_POPUP_TEXT_DOMAIN)
		);

		$fbLikeAlignment = array(
			'left' => __('Left', YPM_POPUP_TEXT_DOMAIN),
			'center' => __('Center', YPM_POPUP_TEXT_DOMAIN),
			'right' => __('Right', YPM_POPUP_TEXT_DOMAIN)
		);

		$devices = array(
			'desktop' => __('Desktop', YPM_POPUP_TEXT_DOMAIN),
			'tablet' => __('Tablet', YPM_POPUP_TEXT_DOMAIN),
			'isiOS' => __('Ios', YPM_POPUP_TEXT_DOMAIN),
			'isAndroid' => __('Android', YPM_POPUP_TEXT_DOMAIN)
		);

		$countries = array(
		);

		$postTypes = apply_filters('ypm-post-types', array(
			YPM_POPUP_POST_TYPE,
			YPM_FACEBOOK_POST_TYPE,
			YPM_YOUTUBE_POST_TYPE,
			YPM_IFRAME_POST_TYPE,
			YPM_SOCIAL_POST_TYPE,
			YPM_CONTACT_POST_TYPE
		));

		$targetDefaultValue = array(array('key1' => 'select_settings'));
		$eventsDefaultValue = array(array('key1' => 'Onload', 'key2' => '0'));

		$options[] = array('name' => 'ypm-events-settings', 'type' => 'array', 'defaultValue' => $eventsDefaultValue);
		$options[] = array('name' => 'ypm-conditions-settings', 'type' => 'array', 'defaultValue' => $targetDefaultValue);
		$options[] = array('name' => 'ypm-display-settings', 'type' => 'array', 'defaultValue' => $targetDefaultValue);
		$options[] = array('name' => 'ypm-popup-width', 'type' => 'string', 'defaultValue' => '640px');
		$options[] = array('name' => 'ypm-popup-height', 'type' => 'string', 'defaultValue' => '480px');
		$options[] = array('name' => 'ypm-popup-max-width', 'type' => 'string', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-popup-max-height', 'type' => 'string', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-popup-dimensions-mode', 'type' => 'string', 'defaultValue' => 'custom');
		$options[] = array('name' => 'ypm-popup-dimensions-auto-size', 'type' => 'string', 'defaultValue' => 'auto');
		$options[] = array('name' => 'ypm-popup-theme', 'type' => 'string', 'defaultValue' => 'colorbox1');
		$options[] = array('name' => 'ypm-esc-key', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-close-button', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-overlay-click', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-overlay-color', 'type' => 'string', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-popup-title', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-delay', 'type' => 'string', 'defaultValue' => 0);
		$options[] = array('name' => 'ypm-z-index', 'type' => 'string', 'defaultValue' => 9999);
		$options[] = array('name' => 'ypm-popup-exit-mode', 'type' => 'string', 'defaultValue' => 'soft');
		$options[] = array('name' => 'ypm-exit-alert-text', 'type' => 'string', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-exit-per-day', 'type' => 'string', 'defaultValue' => '1');
		$options[] = array('name' => 'ypm-exit-page-lavel', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-exit-leave-top', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-popup-exit-enable', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-overlay-opacity', 'type' => 'text', 'defaultValue' => 0.8);
		$options[] = array('name' => 'ypm-is-active', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-facebook-type', 'type' => 'text', 'defaultValue' => 'likeButton');
		$options[] = array('name' => 'ypm-facebook-layout', 'type' => 'text', 'defaultValue' => 'likeButton');
		$options[] = array('name' => 'ypm-facebook-action', 'type' => 'text', 'defaultValue' => 'like');
		$options[] = array('name' => 'ypm-facebook-size', 'type' => 'text', 'defaultValue' => 'small');
		$options[] = array('name' => 'ypm-facebook-url', 'type' => 'text', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-facebook-share-button', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-facebook-like-alignment', 'type' => 'text', 'defaultValue' => 'center');
		$options[] = array('name' => 'ypm-facebook-type', 'type' => 'text', 'defaultValue' => 'center');
		$options[] = array('name' => 'ypm-facebook-share-url', 'type' => 'text', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-facebook-share-layout', 'type' => 'text', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-facebook-share-size', 'type' => 'text', 'defaultValue' => 'small');
		$options[] = array('name' => 'ypm-facebook-share-alignment', 'type' => 'text', 'defaultValue' => 'center');
		$options[] = array('name' => 'ypm-show-on-device-status', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-devices', 'type' => 'array', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-selected-countries-status', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-selected-countries', 'type' => 'array', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-content-click-status', 'type' => 'checkbox', 'defaultValue' => 'on');
		$options[] = array('name' => 'ypm-popup-showing-limitation', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-limitation-shwoing-count', 'type' => 'text', 'defaultValue' => 1);
		$options[] = array('name' => 'ypm-limitation-shwoing-expiration', 'type' => 'text', 'defaultValue' => 1);
		$options[] = array('name' => 'ypm-show-popup-same-user-page-level', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-content-click-count', 'type' => 'text', 'defaultValue' => 1);
		$options[] = array('name' => 'ypm-title-color', 'type' => 'text', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-disable-page-scrolling', 'type' => 'checkbox', 'defaultValue' => '');
		$options[] = array('name' => 'ypm-iframe-url', 'type' => 'text', 'defaultValue' => 'https://www.wikipedia.org/');
		$options[] = array('name' => 'ypm-iframe-width', 'type' => 'text', 'defaultValue' => '300px');
		$options[] = array('name' => 'ypm-iframe-height', 'type' => 'text', 'defaultValue' => '200px');
		// youtube defaults
		$options[] = array('name' => 'ypm-youtube-width', 'type' => 'text', 'defaultValue' => '300px');
		$options[] = array('name' => 'ypm-youtube-height', 'type' => 'text', 'defaultValue' => '300px');
		$options[] = array('name' => 'ypm-youtube-start', 'type' => 'text', 'defaultValue' => '0');


		$YpmDefaults = apply_filters('ypmDefaultOptions', $options);

		$YpmDefaultsData['exitMode'] = $exitMode;
		$YpmDefaultsData['socialShareIn'] = $socialShareIn;
		$YpmDefaultsData['socialThemes'] = $socialThemes;
		$YpmDefaultsData['socialThemeShareCount'] = $socialThemeShareCount;
		$YpmDefaultsData['socialFontSizes'] = $socialFontSizes;
		$YpmDefaultsData['fblikeLayout'] = $fblikeLayout;
		$YpmDefaultsData['fblikeAction'] = $fblikeAction;
		$YpmDefaultsData['fblikeSize'] = $fblikeSize;
		$YpmDefaultsData['postTypes'] = $postTypes;
		$YpmDefaultsData['fbLikeAlignment'] = $fbLikeAlignment;
		$YpmDefaultsData['fblikeShareLayout'] = $fblikeShareLayout;
		$YpmDefaultsData['devices'] = $devices;
		$YpmDefaultsData['countries'] = apply_filters('ypm-countries', $countries);

		$YpmPostTypesInfo['postTypes'] = array(
			YPM_POPUP_POST_TYPE => YPM_POPUP_FREE,
			YPM_FACEBOOK_POST_TYPE => YPM_POPUP_FREE,
			YPM_YOUTUBE_POST_TYPE => YPM_POPUP_FREE,
			YPM_IFRAME_POST_TYPE => YPM_POPUP_SILVER,
			YPM_SOCIAL_POST_TYPE => YPM_POPUP_SILVER,
			YPM_CONTACT_POST_TYPE => YPM_POPUP_GOLD
		);

		$YpmPostTypesInfo['postTypesLabels'] = array(
			YPM_POPUP_POST_TYPE => YPM_POPUP_FREE,
			YPM_FACEBOOK_POST_TYPE => __('Facebook', YPM_POPUP_TEXT_DOMAIN),
			YPM_YOUTUBE_POST_TYPE => __('Youtube', YPM_POPUP_TEXT_DOMAIN),
			YPM_IFRAME_POST_TYPE => __('Iframe', YPM_POPUP_TEXT_DOMAIN),
			YPM_SOCIAL_POST_TYPE => __('Social', YPM_POPUP_TEXT_DOMAIN),
			YPM_CONTACT_POST_TYPE => __('Contact Form', YPM_POPUP_TEXT_DOMAIN)
		);

		$YpmPostTypesInfo['levelLabels'] = array(
			YPM_POPUP_FREE => __('Free', YPM_POPUP_TEXT_DOMAIN),
			YPM_POPUP_SILVER => __('Silver', YPM_POPUP_TEXT_DOMAIN),
			YPM_POPUP_GOLD => __('Gold', YPM_POPUP_TEXT_DOMAIN)
		);
	}
}

DataConfig::init();


